<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Module Name: Pointers
 */
class TB_Pointers_Module extends Themify_Builder_Component_Module {


	public static function get_module_name():string{
		add_filter( 'themify_builder_active_vars', [ __CLASS__, 'builder_active_enqueue' ] );
		return __('Pointers', 'builder-pointers');
	}

	public static function get_json_file():array{
		return ['f'=>Builder_Pointers::$url . 'json/style.json','v'=>Builder_Pointers::get_version()];
	}

	public static function get_module_icon():string{
	    return 'light-bulb';
	}

	public static function get_js_css():array {
		return array(
			'async'=>true,
			'css'=>Builder_Pointers::$url.'assets/style',
			'ver'=>Builder_Pointers::get_version()
		);
	}

	public static function builder_active_enqueue(array $vars ):array {
		if(!isset($vars['addons'])){//backward
			themify_enque_script( 'tb_builder-Pointers', Builder_Pointers::$url . 'assets/active.js', Builder_Pointers::get_version(), [ 'themify-builder-app-js', 'jquery-ui-draggable' ] );
		}
		else{
			wp_enqueue_script('jquery-ui-draggable' );
			$vars['addons'][Builder_Pointers::$url . 'assets/active.js']=Builder_Pointers::get_version();
		}

		$i18n = include dirname( __DIR__ )  . '/includes/i18n.php';
		$vars['i18n']['label']+= $i18n;
		$vars['pointers_vars'] = [
		    'admin_css' => Builder_Pointers::$url . 'assets/admin.css',
		    'v' => Builder_Pointers::get_version(),
			'default_image' => Builder_Pointers::$url.'sample/pointers-ipad-image.jpg',
		];

		return $vars;
	}


	public function __construct() {
            if(method_exists('Themify_Builder_Model', 'add_module')){
                parent::__construct('pointers');
            }
            else{//backward
                 parent::__construct(array(
                    'name' =>$this->get_name(),
                    'slug' => 'pointers',
                    'category' =>$this->get_group()
                ));
            }
	}

    public function get_name(){
		return self::get_module_name();
    }

    public function get_icon(){
		return self::get_module_icon();
    }

    function get_assets() {
		return self::get_js_css();
    }

	public function get_styling() {
		$general = array(
			//bacground
			self::get_expand('bg', array(
				self::get_tab(array(
					'n' => array(
						'options' => array(
							self::get_color('', 'background_color', 'bg_c', 'background-color')
						)
					),
					'h' => array(
						'options' => array(
						    self::get_color('', 'bg_c', 'bg_c', 'background-color','h')
						)
					)
				))
			)),
			// Padding
			self::get_expand('p', array(
				self::get_tab(array(
					'n' => array(
						'options' => array(
							self::get_padding(),

						)
					),
					'h' => array(
						'options' => array(
							self::get_padding('','p','h'),
						)
					)
				))
			)),
			// Margin
			self::get_expand('m', array(
				self::get_tab(array(
					'n' => array(
						'options' => array(
							self::get_margin(),

						)
					),
					'h' => array(
						'options' => array(
							self::get_margin('','m','h'),
						)
					)
				))
			)),
			// Border
            self::get_expand('b', array(
	            self::get_tab(array(
		            'n' => array(
			            'options' => array(
				            self::get_border(),
			            )
		            ),
		            'h' => array(
			            'options' => array(
				            self::get_border('','b','h')
			            )
		            )
	            ))
            )),
			// Width
			self::get_expand('w', array(
				self::get_width('', 'w')
			)),
			// Height & Min Height
			self::get_expand('ht', array(
					self::get_height(),
					self::get_min_height(),
					self::get_max_height()
				)
			),
			// Rounded Corners
			self::get_expand('r_c', array(
					self::get_tab(array(
						'n' => array(
							'options' => array(
								self::get_border_radius()
							)
						),
						'h' => array(
							'options' => array(
								self::get_border_radius('', 'r_c', 'h')
							)
						)
					))
				)
			),
			// Shadow
			self::get_expand('sh', array(
					self::get_tab(array(
						'n' => array(
							'options' => array(
								self::get_box_shadow()
							)
						),
						'h' => array(
							'options' => array(
								self::get_box_shadow('', 'sh', 'h')
							)
						)
					))
				)
			),
			// Display
			self::get_expand('disp', self::get_display())
		);
        return array(
			'type' => 'tabs',
			'options' => array(
				'g' => array(
					'options' => $general
				),
				'm_t' => array(
					'options' => $this->module_title_custom_style()
				)
			)
        );
	}
}

if(!method_exists( 'Themify_Builder_Component_Module', 'get_module_class' )){
	if ( method_exists( 'Themify_Builder_Model', 'add_module' ) ) {
		new TB_Pointers_Module();
	} else {
		Themify_Builder_Model::register_module('TB_Pointers_Module');
	}
}